@@ -1,6 +1,6 @@
 skip_on_cran()
 
-test_that("tbl_survfit(time) works", {
+test_that("tbl_survfit(times) works", {
   expect_silent(
     trial |>
       tbl_survfit(
@@ -22,6 +22,17 @@ test_that("tbl_survfit(probs) works", {
   )
 })
 
+test_that("tbl_survfit works with integer times values", {
+  expect_silent(
+    trial |>
+      tbl_survfit(
+        include = trt,
+        y = "Surv(ttdeath, death)",
+        times = c(6L, 12L)
+      )
+  )
+})
+
 test_that("Using both times and probs errors correctly", {
   expect_error(
     trial |>
